## 2022.10.31.0 (2022-11-01)

[stubsabot] Bump regex to 2022.10.31 (#9050)

Release: https://pypi.org/pypi/regex/2022.10.31
Homepage: https://github.com/mrabarnett/mrab-regex
Diff: https://github.com/mrabarnett/mrab-regex/compare/2022.9.13...2022.10.31

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 3.
 - Total lines of Python code deleted: 2.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 2022.9.13.0 (2022-09-16)

[stubsabot] Bump regex to 2022.9.13 (#8751)

Release: https://pypi.org/project/regex/2022.9.13/
Homepage: https://github.com/mrabarnett/mrab-regex
Diff: https://github.com/mrabarnett/mrab-regex/compare/2022.8.17...2022.9.13

## 2022.8.17.0 (2022-08-19)

[stubsabot] Bump regex to 2022.8.17 (#8562)

Co-authored-by: stubsabot <>

## 2022.7.25.0 (2022-07-29)

[stubsabot] Bump regex to 2022.7.25 (#8432)

Co-authored-by: stubsabot <>

## 2022.7.9.0 (2022-07-15)

[stubsabot] Bump regex to 2022.7.9 (#8300)

Co-authored-by: hauntsaninja <>

## 2022.6.2.0 (2022-06-26)

Bump regex to 2022.6.2 (#8162)

Co-authored-by: AlexWaygood <alex.waygood@gmail.com>

## 2021.11.10.6 (2022-06-21)

`requests`, `regex`: use re-exports instead of assignments in a few places (#8127)

## 2021.11.10.5 (2022-05-11)

regex: accept buffers (#7680)

Similar to #7679

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 2021.11.10.4 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 2021.11.10.3 (2022-02-23)

regex stubs: Add __getitem__ method to Match (#7372)

## 2021.11.10.2 (2022-01-07)

Update pyright (#6840)

## 2021.11.10.0 (2021-12-30)

Add regex stubs (#6713)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Akuli <akuviljanen17@gmail.com>

